@@ -2,7 +2,7 @@ from matplotlib import pyplot as plt
 
 from ml_tooling.plots import plot_residuals, plot_prediction_error
 from ml_tooling.plots.viz.baseviz import BaseVisualize
-from ml_tooling.config import MPL_STYLESHEET
+from ml_tooling.config import config
 
 
 class RegressionVisualize(BaseVisualize):
@@ -20,7 +20,7 @@ class RegressionVisualize(BaseVisualize):
         matplotlib.Axes
             Plot of the estimator's residuals
         """
-        with plt.style.context(MPL_STYLESHEET):
+        with plt.style.context(config.STYLE_SHEET):
             title = f"Residual Plot - {self._estimator_name}"
             y_pred = self._estimator.predict(self._data.test_x)
             return plot_residuals(self._data.test_y, y_pred, title, **kwargs)
@@ -36,7 +36,7 @@ class RegressionVisualize(BaseVisualize):
             Plot of the estimator's prediction error
         """
 
-        with plt.style.context(MPL_STYLESHEET):
+        with plt.style.context(config.STYLE_SHEET):
             title = f"Prediction Error - {self._estimator_name}"
             y_pred = self._estimator.predict(self._data.test_x)
             return plot_prediction_error(
