@@ -8,7 +8,19 @@ class DFStandardScaler(BaseEstimator, TransformerMixin):
     :class:`~sklearn.preprocessing.StandardScaler`
     """
 
-    def __init__(self, copy=True, with_mean=True, with_std=True):
+    def __init__(
+        self, copy: bool = True, with_mean: bool = True, with_std: bool = True
+    ):
+        """
+        Parameters
+        ----------
+        copy: bool
+            If True, a copy of the dataframe is made.
+        with_mean: bool
+            If True, center the data before scaling.
+        with_std: bool
+            If True, scale the data to unit standard deviation.
+        """
         self.with_mean = with_mean
         self.with_std = with_std
         self.copy = copy
