@@ -1,4 +1,4 @@
-from typing import Union, List, Optional
+from typing import Union, List
 
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
@@ -11,7 +11,13 @@ class Select(BaseEstimator, TransformerMixin):
     Selects columns from DataFrame
     """
 
-    def __init__(self, columns: Optional[Union[List[str], str]] = None):
+    def __init__(self, columns: Union[List[str], str] = None):
+        """
+        Parameters
+        ----------
+        columns: List[str], str, None
+            Specify which columns are selected.
+        """
         self.columns = columns
 
     def fit(self, X: pd.DataFrame, y=None):
